==> gap-grape_4.8.5+ds.orig.tar.xz: gap-grape-4.8.5+ds/README.md <==

The GRAPE 4.8.5 Package for GAP
===============================

GRAPE is a GAP package for computing with graphs and groups, 
by Leonard H. Soicher, with contributions from Steve Linton, Alexander
Hulpke, Jerry James and Max Horn, and including Brendan McKay's nauty 2.2 
(final patched version) package.

The GRAPE package and the source included with this distribution are
copyright (C) Leonard Soicher 1992-2021, except for the following:

- Brendan McKay's nauty 2.2 system; see the nauty copyright notice in
file nauty22/nauty-h.in
- Steve Linton's SmallestImageSet function in lib/smallestimage.g

Except for Brendan McKay's nauty 2.2 package, GRAPE is licensed under the
terms of the GNU General Public License as published by the Free Software
Foundation; either version 2 of the License, or (at your option) any
later version. For details, see <http://www.gnu.org/licenses/gpl.html>.

Referencing GRAPE
-----------------

Please reference your use of the GRAPE package in a published work
as follows:

L.H. Soicher, The GRAPE package for GAP, Version 4.8.5, 2021,
<https://gap-packages.github.io/grape>.

Questions, remarks, suggestions, and issues
-------------------------------------------

For questions, remarks, suggestions, and issues, please use the 
issue tracker at <https://github.com/gap-packages/grape/issues>.

Installing GRAPE
----------------

The official GAP Windows distribution includes the GRAPE package
fully installed.  Thus, GRAPE normally requires no further installation
for Windows users of GAP. What follows is for Unix users of GRAPE.

You do not need to download and unpack an archive for GRAPE
unless you want to install the package separately from your main
GAP installation or are installing an upgrade of GRAPE to an
existing installation of GAP.  If you do need to download
GRAPE, you can find the latest archive .tar.gz file for the 
package at <https://gap-packages.github.io/grape>.

Installation and testing instructions for the GRAPE package
can be found in Chapter 1 of the GRAPE manual, available from
<https://gap-packages.github.io/grape>.

==> gap-grape_4.9.0+ds.orig.tar.xz: gap-grape-4.9.0+ds/README.md <==

The GRAPE 4.9.0 Package for GAP
===============================

GRAPE is a GAP package for computing with graphs and groups, by 
Leonard Soicher, with contributions from Steve Linton, Alexander
Hulpke, Jerry James and Max Horn, and including Brendan McKay's nauty
(Version 2.8.6) package.

The GRAPE package and the source included with this distribution are
copyright (C) Leonard Soicher 1992-2022, except for the following:

- the nauty 2.8.6 package; see the copyright notice in the file
nauty2_8_6/COPYRIGHT
- Steve Linton's SmallestImageSet function in lib/smallestimage.g

Except for the nauty 2.8.6 package, which is licensed under the Apache
License 2.0, GRAPE is licensed under the terms of the GNU General Public
License as published by the Free Software Foundation; either version
2 of the License, or (at your option) any later version. For details,
see <https://www.gnu.org/licenses/gpl.html>.

Referencing GRAPE
-----------------

Please reference your use of the GRAPE package in a published work
as follows:

L.H. Soicher, The GRAPE package for GAP, Version 4.9.0, 2022,
<https://gap-packages.github.io/grape>.

Questions, remarks, suggestions, and issues
-------------------------------------------

For questions, remarks, suggestions, and issues, please use the 
issue tracker at <https://github.com/gap-packages/grape/issues>.

Installing GRAPE
----------------

The official GAP Windows distribution includes the GRAPE package
fully installed.  Thus, GRAPE normally requires no further installation
for Windows users of GAP. What follows is for Unix users of GRAPE.

You do not need to download and unpack an archive for GRAPE
unless you want to install the package separately from your main
GAP installation or are installing an upgrade of GRAPE to an
existing installation of GAP.  If you do need to download
GRAPE, you can find the latest archive .tar.gz file for the 
package at <https://gap-packages.github.io/grape>.

Installation and testing instructions for the GRAPE package
can be found in Chapter 1 of the GRAPE manual, available from
<https://gap-packages.github.io/grape>.
